Exception: Keiyaku::HTTPError
- Defined in:
- sig/keiyaku.rbs,
lib/keiyaku/runtime.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#body ⇒ String?
readonly
Returns the value of attribute body.
-
#headers ⇒ Hash[String, String]
readonly
Returns the value of attribute headers.
-
#parsed ⇒ Object
readonly
The decoded body: a model if the operation documents a schema for this status, otherwise whatever JSON.parse returned.
-
#status ⇒ Integer
readonly
Returns the value of attribute status.
Instance Method Summary collapse
-
#initialize(status:, headers:, body:, parsed: nil) ⇒ HTTPError
constructor
A new instance of HTTPError.
Constructor Details
#initialize(status:, headers:, body:, parsed: nil) ⇒ HTTPError
Returns a new instance of HTTPError.
33 |
# File 'sig/keiyaku.rbs', line 33
def initialize: (status: Integer, headers: Hash[String, String], body: String?, ?parsed: untyped) -> void
|
Instance Attribute Details
#body ⇒ String? (readonly)
Returns the value of attribute body.
27 28 29 |
# File 'sig/keiyaku.rbs', line 27 def body @body end |
#headers ⇒ Hash[String, String] (readonly)
Returns the value of attribute headers.
26 27 28 |
# File 'sig/keiyaku.rbs', line 26 def headers @headers end |
#parsed ⇒ Object (readonly)
The decoded body: a model if the operation documents a schema for this status, otherwise whatever JSON.parse returned.
31 32 33 |
# File 'sig/keiyaku.rbs', line 31 def parsed @parsed end |
#status ⇒ Integer (readonly)
Returns the value of attribute status.
25 26 27 |
# File 'sig/keiyaku.rbs', line 25 def status @status end |